# This file

This file contains instructions using the reproducible research provided with the paper But clouds got in my way: Bias and bias correction of VIIRS nighttime lights data in the presence of clouds by Ayush Patnaik, Ajay Shah, Anshul Tayal & Susan Thomas. The paper examines the downward bias in VIIRS nighttime lights during cloudy months and provides a partial bias correction scheme.  

Landing page of the paper: https://xkdr.org/releases/PatnaikShahTayalThomas_2021_bias_correction_nighttime_lights.html

Citation: But clouds got in my way: Bias and bias correction of VIIRS nighttime lights data in the presence of clouds, Ayush Patnaik, Ajay Shah, Anshul Tayal, Susan Thomas, xKDR Working Paper 7, October 2021.

# Reproducible research

Full methodologies for the new scheme and conventional cleaning are implemented for the city of Bombay in the SRC folder. The raw data from the DATA directory are used as input and cleaned outputs are in the results folder. Figure 1,2,3,5,7,8,9 from the paper are also reproduced.  

Go into the SRC folder. 
1) To generate the new and conventional datasets, run:
$ make datasets 
2) To generate the plots of the paper, run: 
$ make plots

## R_3.6.1 packages required
The following packages are required to run the make file. 

pracma_2.3.3
zoo_1.8-8
stringr_1.4.0      
forecast_8.13
data.table_1.13.6
dplyr_1.0.4        
ggfortify_0.4.11
ggplot2_3.3.3
seasonal_1.7.1     
plyr_1.8.6
rhdf5_2.30.1       
readr_1.4.0
BiocManager_1.30.10

## Data 

1) Nighttime lights raw radiances for a box around Bombay are stored in DATA/raw_radiance_datacube_Bombay.jld and the number of cloud-free observations for each of those pixels are stored in DATA/cfobs_datacube_Bombay.jld

These files are three-dimensional arrays. Values outside Bombay's boundary have been made zero so that it's easy and fast to compute the total light of the city. 

2) The time series of World Bank's estimate for nighttime lights of Bombay, the time series of aggregate income of Bombay estimated using CMIE CPHS and the time series of the sample pixel in Bombay used as example in the paper are in the file DATA/other_timeseries.csv
These are needed to generate the plots. 


## Libraries 

There are 2 libraries: 
1) bias_correction.R 
2) Commons.R

bias_correction.R implements our scheme for the timeseries of a pixel.

Commons.R has functions to perform conventional cleaning and generate plots. 


## Results 

The following figures from the paper are generated in the RESULTS folder. 

Figure 1: radiance_rawPixelLevel_incomeReal_HR_Bombay.png
Figure 2: radiance_cfobs_px1_noiseRm_out_interpolated.png
Figure 3: radiance_cfobs_noiseRm_out_interpolated_HR_Bombay.png
Figure 5: seasonality_incomeReal_conventional_HR_Bombay_lineplot.png
Figure 7: radiance_cfobs_px1_noiseRm_out_interpolated_timeRem_loess.png
Figure 8: radiance_conventional_bcPixelLevel_HR_Bombay.png
Figure 9: radiance_cfobs_px1_noiseRm_out_interpolated_timeRem_loess.png

The data files for conventionally cleaned and the new nighttime lights are also produced in the RESULTS folder as conventional_datacube_Bombay and new_datacube_Bombay respectively. 

## Notes

Under conventional cleaning, the paper suggests removing all pixels with detrended standard deviation of more than the 99.9th percentile. Since this figure is different for Bombay (used as example here) and India, we are using the figure for India, which is 11.9. 

