library(BiocManager)
#BiocManager::install("rhdf5")
library(readr)
library(rhdf5)

## Loading common functions used to apply other functions on the dataset
source("Commons.R")
## Loading datasets generated for reproducible research 
#number of cloud-free observations for each pixel
clouds_Bombay         <- h5read("../DATA/cfobs_datacube_Bombay.jld", "data") 
#pixel level radiance for Bombay
radiance_Bombay       <- h5read("../DATA/raw_radiance_datacube_Bombay.jld", "data")  
## Stepwise cleaning
## Conventional cleaning
conventional_cleaning <- function(radiance, cfobs)
{
    print ("Conventional cleaning in process")
    tmp         <- radiance
    print("Making observations with 0 cloud-free observations as NA")    
    tmp         <- mark_na(radiance, cfobs)
    print("Replacing negative values with NA")
    tmp         <- long_apply(tmp, threshold_apply)
    print("Removing outliers using tsclean")
    tmp         <- long_apply(tmp, OutlierRem)
    print("Generating a background noise mask")   
    noiseMask   <- noise_mask_generator(tmp, cfobs)
    print("Removing background noise")
    tmp         <- apply_mask(tmp, noiseMask)
    print("Generating an outlier pixels mask: pixels with standard deviation less than 11.9") # 11.9 is 99.9th percentile of standard deviation of all lit pixels in India. 
    outlierMask <- outlier_mask_generator(tmp, noiseMask)
    print("Applying outlier mask to remove outlier pixels")
    tmp         <- apply_mask(tmp, outlierMask)
    tmp         <- long_apply(tmp, interpolate)
    print("Interpolating to fill for NAs.")
    return(tmp)
}
## Our proposed scheme
new_cleaning <- function(radiance, cfobs)
{
    print("Cleaning using proposed scheme in process")
    tmp         <- radiance
    print("Making observations with 0 cloud-free observations as NA")
    tmp         <- mark_na(radiance, cfobs)
    print("Replacing negative values with NA")
    tmp     <- long_apply(tmp, threshold_apply)
    print("Removing outliers using tsclean")
    tmp     <- long_apply(tmp, OutlierRem)
    print("Generating a background noise mask")
    noiseMask   <- noise_mask_generator(tmp, cfobs)
    print("Removing background noise")
    tmp         <- apply_mask(tmp, noiseMask)
    print("Generating an outlier pixels mask: pixels with standard deviation less than 11.9")# 11.9 is 99.9th percentile of standard deviation of all lit pixels in India.
    outlierMask <- outlier_mask_generator(tmp, noiseMask)
    print("Applying outlier mask to remove outlier pixels")
    tmp         <- apply_mask(tmp, outlierMask)
    print("Performing bias correction")
    tmp     <- bias_correction_ts(tmp, cfobs, noiseMask*outlierMask)
    print("Interpolating to fill for NAs.")
    tmp     <- long_apply(tmp, interpolate)
    print("New cleaning method finished.")
    return(tmp)
}

# Computing the radiance using conventional cleaning and our proposed scheme. 
conventional_Bombay     <- conventional_cleaning(radiance_Bombay, clouds_Bombay)
new_Bombay              <- new_cleaning(radiance_Bombay, clouds_Bombay)

## Writing the conentionally cleaned and bias corrected file

h5write(conventional_Bombay, "../RESULTS/conventional_datacube_Bombay.jld","data")

h5write(new_Bombay, "../RESULTS/new_datacube_Bombay.jld","data")
print("Conventionally cleaned and new JLD files are saved in RESULTS/")

